baseObjects

|  | ## Cheshire3: baseObjects Module

Module baseObjects

Classes | [hide private]
Server | A Server object is a collection point for other objects, and an initial entry into the system for requests from a ProtocolHandler.
Database | A Database is a collection of Records and Indexes.
Index | An Index is an object which defines an access point into records and is responsable for extracting that information from them.
XPathProcessor | An XPathProcessor is a simple wrapper around an XPath.
Extractor | An Extractor is a processing object called by an Index with the value of an evaluated XPath expression or with a string.
Normalizer | Normalizer objects are chained after Extractors in order to transform the data from the record or query.
DocumentFactory | Object Docs
QueryFactory |
Parser | Normally a simple wrapper around an XML parser, these objects can be viewed as Record Factories.
PreParser | A PreParser takes a Document and creates a second one.
Transformer | A Transformer is the opposite of a Parser.
User | An object representing a user of the system to allow for convenient access to properties such as username, password and rights metadata.
ProtocolMap | Protocol maps map from an incoming query type to internal indexes based on some specification.
IndexStore | A persistent storage mechanism for extracted terms.
ObjectStore | An interface to a persistent storage mechanism for configured Cheshire3 objects.
QueryStore | An interface to persistent storage for Queries.
RecordStore | A persistent storage mechanism for Records.
DocumentStore | An interface to a persistent storage mechanism for Documents and their associated metadata.
ResultSetStore | A persistent storage mechanism for result sets.
Document | A Document is the raw data which will become a record.
ResultSet | A collection of records, typically created as the result of a search on a database.
ResultSetItem | An object representing a pointer to a Record, with result set specific metadata.
Record | Records in the system are stored in an XML form.
Session | An object to be passed around amongst the processing objects to maintain a session.
Workflow | A workflow is similar to the process chain concept of an index, but behaves at a more global level.
Logger |